==> mgb-0.5.4.4-de.zip: email.php <==
<?php
	/*
	MGB 0.5.4.4
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         include ("settings.php");
         include ("language/lang_main.php");

         if($_GET[id]!="admin")
         	{
         	$sql="SELECT email, name FROM $db[entrys] WHERE id=".$_GET[id]." ORDER BY ID DESC";
	        $link=mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
	        mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
	        $result=mysql_query($sql, $link) or die ("MySQL Fehler");

         	for($i=0;$i<mysql_num_rows($result);$i++)
         		{
			$eintrag[$i]=mysql_fetch_array($result);
			}

        		for($i=0;$i<count($eintrag);$i++)
         		{
                         $useremail=$eintrag[$i][email];
                 	$username=$eintrag[$i][name];
                 	}

                 // Quake Farbcodes ausfiltern
                 if(strstr($username,"^0")){$username=str_replace("^0","",$username);}
                 if(strstr($username,"^1")){$username=str_replace("^1","",$username);}
                 if(strstr($username,"^2")){$username=str_replace("^2","",$username);}
                 if(strstr($username,"^3")){$username=str_replace("^3","",$username);}
                 if(strstr($username,"^4")){$username=str_replace("^4","",$username);}
                 if(strstr($username,"^5")){$username=str_replace("^5","",$username);}
                 if(strstr($username,"^6")){$username=str_replace("^6","",$username);}
                 if(strstr($username,"^7")){$username=str_replace("^7","",$username);}
                 if(strstr($username,"^9")){$username=str_replace("^9","",$username);}

                 }
         else
         	{
                 $useremail = $settings['adminemail'];
                 $username = $lang['send_email_to_admin'];
                 }


if($_POST[sent]==1)
         {
         $_POST[name]=str_replace('~','',strip_tags(trim($_POST[name])));
         $_POST[betreff]=str_replace('~','',strip_tags(trim($_POST[betreff])));
         $_POST[message]=str_replace('~','',strip_tags(trim($_POST[message])));

         // Fehlermeldungen
         if(!$_POST[message]){$fehler=$lang['failuremessage1'];}
         if(!$_POST[betreff]){$fehler=$lang['failuremessage6'];}
         if(!$_POST[email]){$fehler=$lang['failuremessage2'];}
         if(!$_POST[name]){$fehler=$lang['failuremessage3'];}
         if($fehler)
         	{
                 $fehler="<font class='fehler'>".$fehler."</font>";
                 $ausgabe="<form action='".$PHP_SELF."?id=".$_GET[id]."' method='post'>\n";
                 $ausgabe.="<table summary='email schreiben' class='rahmen_eintragen' style='width:90%;border:none' cellspacing='0' cellpadding='0'>\n";
		$ausgabe.="<tr>\n";
		$ausgabe.="<td class='rahmen_eintragen'>\n";
		$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
		$ausgabe.="<center>\n";
		$ausgabe.="<table summary='email schreiben' class='eintragen' style='width:400px;border:none;'>\n";
		$ausgabe.="<tr>\n";
		$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
		$ausgabe.="<font>".$lang['name']."</font>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
		$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='name' size='30' value='".$_POST[name]."'>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
		$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
		$ausgabe.="<font>".$lang['eMail']."</font>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
		$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='email' size='30' value='".$_POST[email]."'>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
		$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
		$ausgabe.="<font>".$lang['subject']."</font>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
		$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='betreff' size='30' value='".$_POST[betreff]."'>\n";
		$ausgabe.="</tr>\n";
		$ausgabe.="<tr>\n";
		$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
		$ausgabe.="<font>".$lang['message']."</font>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
		$ausgabe.="<textarea style='".$settings['inputtextstyle']."' name='message' rows='5' cols='23'>".$_POST[message]."</textarea>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="</tr>\n";
		$ausgabe.="</table>\n";
		$ausgabe.="<br>\n";
		$ausgabe.="<font>[".$lang['all_fields_mandatory']."]</font><br><br>\n";
		$ausgabe.="<input type='submit' value='".$lang['send_email']."' style='".$settings['inputtextstyle']."'>\n";
		$ausgabe.="</center>\n";
                 $ausgabe.="</td>\n";
		$ausgabe.="</tr>\n";
		$ausgabe.="</table>\n";
		$ausgabe.="</form>\n";
                 }

         if($_POST[name] AND $_POST[email] AND $_POST[betreff] AND $_POST[message])   // Formular wurde ausgefllt.
         	{

                 include ("functions.php");

                 if(check_mail($_POST[email]))
                 	{
         		mail($useremail, $_POST[betreff], $_POST[message]."\n\n\n".$lang['email_sender'].": ".$_POST[name]."\n".$lang['email_from']." ".$settings['hpname']."\n\n".$settings['hpadresse']."\n".$settings['adminemail'], "from: ".$_POST[email]); // Mail an den User schicken

                         $ausgabe="<table summary='email verschicken erfolgreich' class='rahmen_eintragen' style='width:90%;height:150px;border:none' cellspacing='0' cellpadding='0'>";
         		$ausgabe.="<tr>\n";
			$ausgabe.="<td class='rahmen_eintragen'>\n";
			$ausgabe.="<center>\n";
			$ausgabe.="<table summary='email verschicken erfolgreich' class='eintragen' style='width:300px;border:none'>\n";
			$ausgabe.="<tr>\n";
			$ausgabe.="<td class='eintragen'>\n";
         		$ausgabe.="<center>\n";
			$ausgabe.="<font>".$lang['email_sent']."<br><br><a href='guestbook.php'>".$lang['forwarding']."</a></font>\n";
                         $ausgabe.="</center>\n";
                         $ausgabe.="</td>\n";
         		$ausgabe.="</tr>\n";
         		$ausgabe.="</table>\n";
         		$ausgabe.="</center>\n";
         		$ausgabe.="</td>\n";
         		$ausgabe.="</tr>\n";
         		$ausgabe.="</table>\n";
         		$refresh="<meta http-equiv='refresh' content='5; URL=guestbook.php'>";
                         }
                 else
                 	{
                         $fehler="<font class='fehler'>".$_POST[email]."&nbsp;".$lang['failuremessage5']."</font>";
                         $ausgabe="<form action='".$PHP_SELF."?id=".$_GET[id]."' method='post'>\n";
                 	$ausgabe.="<table summary='email schreiben' class='rahmen_eintragen' style='width:90%;border:none' cellspacing='0' cellpadding='0'>\n";
			$ausgabe.="<tr>\n";
			$ausgabe.="<td class='rahmen_eintragen'>\n";
			$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
			$ausgabe.="<center>\n";
			$ausgabe.="<table summary='email schreiben' class='eintragen' style='width:300px;border:none;'>\n";
			$ausgabe.="<tr>\n";
			$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
			$ausgabe.="<font>".$lang['name']."</font>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
			$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='name' size='30' value='".$_POST[name]."'>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="</tr>\n";
                 	$ausgabe.="<tr>\n";
			$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
			$ausgabe.="<font>".$lang['eMail']."</font>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
			$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='email' size='30' value='".$_POST[email]."'>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="</tr>\n";
                 	$ausgabe.="<tr>\n";
			$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
			$ausgabe.="<font>".$lang['subject']."</font>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
			$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='betreff' size='30' value='".$_POST[betreff]."'>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="</tr>\n";
			$ausgabe.="<tr>\n";
			$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
			$ausgabe.="<font>".$lang['message']."</font>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
			$ausgabe.="<textarea style='".$settings['inputtextstyle']."' name='message' rows='5' cols='23'>".$_POST[message]."</textarea>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="</tr>\n";
			$ausgabe.="</table>\n";
			$ausgabe.="<br>\n";
			$ausgabe.="<font>[".$lang['all_fields_mandatory']."]</font><br><br>\n";
			$ausgabe.="<input type='submit' value='".$lang['send_email']."' style='".$settings['inputtextstyle']."'>\n";
			$ausgabe.="</center>\n";
                 	$ausgabe.="</td>\n";
			$ausgabe.="</tr>\n";
			$ausgabe.="</table>\n";
			$ausgabe.="</form>\n";
	                }
                 }
         }
else
	{
        	$ausgabe="<form action='".$PHP_SELF."?id=".$_GET[id]."' method='post'>\n";
        	$ausgabe.="<table summary='email schreiben' class='rahmen_eintragen' style='width:90%;border:none' cellspacing='0' cellpadding='0'>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='rahmen_eintragen'>\n";
	$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
	$ausgabe.="<center>\n";
	$ausgabe.="<table summary='email schreiben' class='eintragen' style='width:400px;border:none;'>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
	$ausgabe.="<font>".$lang['name']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
        	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='name' size='30' value='".$_POST[name]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
	$ausgabe.="<font>".$lang['eMail']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='email' size='30' value='".$_POST[email]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
        	$ausgabe.="<tr>\n";
        	$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
	$ausgabe.="<font>".$lang['subject']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='betreff' size='30' value='".$_POST[betreff]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
	$ausgabe.="<font>".$lang['message']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
	$ausgabe.="<textarea style='".$settings['inputtextstyle']."' name='message' rows='5' cols='23'>".$_POST[message]."</textarea>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="</table>\n";
	$ausgabe.="<br>\n";
	$ausgabe.="<font>[".$lang['all_fields_mandatory']."]</font><br><br>\n";
	$ausgabe.="<input type='submit' value='".$lang['send_email']."' style='".$settings['inputtextstyle']."'>\n";
	$ausgabe.="</center>\n";
        	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="</table>\n";
	$ausgabe.="</form>\n";
        	}

	include ("header.php");
?>
<div style="padding:10px">
<center>
<table summary='eintragen' class="rahmen" cellspacing="0" cellpadding="5">
	<tr>
		<td class="rahmen_titel">
                 <font style="color:<?php echo $settings['ueberschriftfarbe']; ?>"><b><?php echo $lang['title_message_send_email_before_name']."&nbsp;".$username."&nbsp;".$lang['title_message_send_email_after_name']; ?></b></font>
                 </td>
	</tr>
	<tr>
         	<td class="rahmen_eintraege">
                 <center>
                 <br>
                 <?php
                 	echo "<div style='padding-bottom:7px'>".$fehler."</div>";
                         echo $ausgabe;
                 ?>
                 </center>
		</td>
	</tr>
</table>
<div style="padding:10px"><font><a href='guestbook.php'><?php echo $lang['back_to_gb']; ?></a></font></div></center>
<?php
	include ("copyright.php");
?>
</div>
<?php
	include ("footer.php");
?>

==> mgb-0.5.4.6-de.zip: email.php <==
<?php
	/*
	MGB 0.5.4.6
	Copyright (C) 2004 - 2007  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

        require ("settings.php");
        require ("functions.php");
        require ("language/lang_main.php");
        
        $getid = htmlspecialchars(stripslashes(strip_tags(trim($_GET[id]))), ENT_QUOTES);

        if($getid != "admin")
         	{
         	$link = mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
         	
         	$query = "SELECT email, name FROM $db[entrys] WHERE id='".$getid."' LIMIT 1";         	
	        
	        mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
	        $result = mysql_query($query) or die ("MySQL Fehler");

         	for($i=0;$i<mysql_num_rows($result);$i++)
         		{
			$eintrag[$i]=mysql_fetch_array($result);
			}

        		for($i=0;$i<count($eintrag);$i++)
         		{
                         $useremail = $eintrag[$i][email];
                 	 $username = $eintrag[$i][name];
                 	}

                // Quake Farbcodes ausfiltern
                if(strstr($username,"^0")){$username=str_replace("^0","",$username);}
                if(strstr($username,"^1")){$username=str_replace("^1","",$username);}
                if(strstr($username,"^2")){$username=str_replace("^2","",$username);}
                if(strstr($username,"^3")){$username=str_replace("^3","",$username);}
                if(strstr($username,"^4")){$username=str_replace("^4","",$username);}
                if(strstr($username,"^5")){$username=str_replace("^5","",$username);}
                if(strstr($username,"^6")){$username=str_replace("^6","",$username);}
                if(strstr($username,"^7")){$username=str_replace("^7","",$username);}
                if(strstr($username,"^9")){$username=str_replace("^9","",$username);}

		}
         else
		{
                $useremail = $settings['adminemail'];
                $username = $lang['send_email_to_admin'];
                }


if($_POST[sent]==1)
         {
         $_POST[name] = htmlspecialchars(stripslashes(strip_tags(trim($_POST[name]))), ENT_QUOTES);
         $_POST[betreff] = htmlspecialchars(stripslashes(strip_tags(trim($_POST[betreff]))), ENT_QUOTES);
         $_POST[message] = htmlspecialchars(stripslashes(strip_tags(trim($_POST[message]))), ENT_QUOTES);         

         // Fehlermeldungen
         if(!$_POST[message]){$fehler=$lang['failuremessage1'];}
         if(!$_POST[betreff]){$fehler=$lang['failuremessage6'];}
         if(!$_POST[email]){$fehler=$lang['failuremessage2'];}
         if(!$_POST[name]){$fehler=$lang['failuremessage3'];}
         if($fehler)
         	{
                $fehler="<font class='fehler'>".$fehler."</font>";
                $ausgabe="<form action='".$PHP_SELF."?id=".$getid."' method='post'>\n";
                $ausgabe.="<table summary='email schreiben' class='rahmen_eintragen' style='width:90%;border:none' cellspacing='0' cellpadding='0'>\n";
		$ausgabe.="<tr>\n";
		$ausgabe.="<td class='rahmen_eintragen'>\n";
		$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
		$ausgabe.="<center>\n";
		$ausgabe.="<table summary='email schreiben' class='eintragen' style='width:400px;border:none;'>\n";
		$ausgabe.="<tr>\n";
		$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
		$ausgabe.="<font>".$lang['name']."</font>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
		$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='name' size='30' value='".$_POST[name]."'>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="</tr>\n";
                $ausgabe.="<tr>\n";
		$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
		$ausgabe.="<font>".$lang['eMail']."</font>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
		$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='email' size='30' value='".$_POST[email]."'>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="</tr>\n";
                $ausgabe.="<tr>\n";
		$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
		$ausgabe.="<font>".$lang['subject']."</font>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
		$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='betreff' size='30' value='".$_POST[betreff]."'>\n";
		$ausgabe.="</tr>\n";
		$ausgabe.="<tr>\n";
		$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
		$ausgabe.="<font>".$lang['message']."</font>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
		$ausgabe.="<textarea style='".$settings['inputtextstyle']."' name='message' rows='5' cols='23'>".$_POST[message]."</textarea>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="</tr>\n";
		$ausgabe.="</table>\n";
		$ausgabe.="<br>\n";
		$ausgabe.="<font>[".$lang['all_fields_mandatory']."]</font><br><br>\n";
		$ausgabe.="<input type='submit' value='".$lang['send_email']."' style='".$settings['inputtextstyle']."'>\n";
		$ausgabe.="</center>\n";
                $ausgabe.="</td>\n";
		$ausgabe.="</tr>\n";
		$ausgabe.="</table>\n";
		$ausgabe.="</form>\n";
                }

         if($_POST[name] AND $_POST[email] AND $_POST[betreff] AND $_POST[message])   // Formular wurde ausgefllt.
         	{

                 require ("functions.php");

                 if(check_mail($_POST[email]))
                 	{
         		mail($useremail, $_POST[betreff], $_POST[message]."\n\n\n".$lang['email_sender'].": ".$_POST[name]."\n".$lang['email_from']." ".$settings['hpname']."\n\n".$settings['hpadresse']."\n".$settings['adminemail'], "from: ".$_POST[email]); // Mail an den User schicken

                        $ausgabe="<table summary='email verschicken erfolgreich' class='rahmen_eintragen' style='width:90%;height:150px;border:none' cellspacing='0' cellpadding='0'>";
         		$ausgabe.="<tr>\n";
			$ausgabe.="<td class='rahmen_eintragen'>\n";
			$ausgabe.="<center>\n";
			$ausgabe.="<table summary='email verschicken erfolgreich' class='eintragen' style='width:300px;border:none'>\n";
			$ausgabe.="<tr>\n";
			$ausgabe.="<td class='eintragen'>\n";
         		$ausgabe.="<center>\n";
			$ausgabe.="<font>".$lang['email_sent']."<br><br><a href='guestbook.php'>".$lang['forwarding']."</a></font>\n";
                        $ausgabe.="</center>\n";
                        $ausgabe.="</td>\n";
         		$ausgabe.="</tr>\n";
         		$ausgabe.="</table>\n";
         		$ausgabe.="</center>\n";
         		$ausgabe.="</td>\n";
         		$ausgabe.="</tr>\n";
         		$ausgabe.="</table>\n";
         		$refresh="<meta http-equiv='refresh' content='5; URL=guestbook.php'>";
                        }
                 else
                 	{
                        $fehler="<font class='fehler'>".$_POST[email]."&nbsp;".$lang['failuremessage5']."</font>";
                        $ausgabe="<form action='".$PHP_SELF."?id=".$getid."' method='post'>\n";
                 	$ausgabe.="<table summary='email schreiben' class='rahmen_eintragen' style='width:90%;border:none' cellspacing='0' cellpadding='0'>\n";
			$ausgabe.="<tr>\n";
			$ausgabe.="<td class='rahmen_eintragen'>\n";
			$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
			$ausgabe.="<center>\n";
			$ausgabe.="<table summary='email schreiben' class='eintragen' style='width:300px;border:none;'>\n";
			$ausgabe.="<tr>\n";
			$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
			$ausgabe.="<font>".$lang['name']."</font>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
			$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='name' size='30' value='".$_POST[name]."'>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="</tr>\n";
                 	$ausgabe.="<tr>\n";
			$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
			$ausgabe.="<font>".$lang['eMail']."</font>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
			$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='email' size='30' value='".$_POST[email]."'>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="</tr>\n";
                 	$ausgabe.="<tr>\n";
			$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
			$ausgabe.="<font>".$lang['subject']."</font>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
			$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='betreff' size='30' value='".$_POST[betreff]."'>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="</tr>\n";
			$ausgabe.="<tr>\n";
			$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
			$ausgabe.="<font>".$lang['message']."</font>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
			$ausgabe.="<textarea style='".$settings['inputtextstyle']."' name='message' rows='5' cols='23'>".$_POST[message]."</textarea>\n";
			$ausgabe.="</td>\n";
			$ausgabe.="</tr>\n";
			$ausgabe.="</table>\n";
			$ausgabe.="<br>\n";
			$ausgabe.="<font>[".$lang['all_fields_mandatory']."]</font><br><br>\n";
			$ausgabe.="<input type='submit' value='".$lang['send_email']."' style='".$settings['inputtextstyle']."'>\n";
			$ausgabe.="</center>\n";
                 	$ausgabe.="</td>\n";
			$ausgabe.="</tr>\n";
			$ausgabe.="</table>\n";
			$ausgabe.="</form>\n";
	                }
                 }
        }
else
	{
        $ausgabe="<form action='".$PHP_SELF."?id=".$getid."' method='post'>\n";
        $ausgabe.="<table summary='email schreiben' class='rahmen_eintragen' style='width:90%;border:none' cellspacing='0' cellpadding='0'>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='rahmen_eintragen'>\n";
	$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
	$ausgabe.="<center>\n";
	$ausgabe.="<table summary='email schreiben' class='eintragen' style='width:400px;border:none;'>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
	$ausgabe.="<font>".$lang['name']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
        $ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='name' size='30' value='".$_POST[name]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
	$ausgabe.="<font>".$lang['eMail']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='email' size='30' value='".$_POST[email]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
        $ausgabe.="<tr>\n";
        $ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
	$ausgabe.="<font>".$lang['subject']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='betreff' size='30' value='".$_POST[betreff]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:120px' align='right'>\n";
	$ausgabe.="<font>".$lang['message']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:225px' align='center'>\n";
	$ausgabe.="<textarea style='".$settings['inputtextstyle']."' name='message' rows='5' cols='23'>".$_POST[message]."</textarea>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="</table>\n";
	$ausgabe.="<br>\n";
	$ausgabe.="<font>[".$lang['all_fields_mandatory']."]</font><br><br>\n";
	$ausgabe.="<input type='submit' value='".$lang['send_email']."' style='".$settings['inputtextstyle']."'>\n";
	$ausgabe.="</center>\n";
        $ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="</table>\n";
	$ausgabe.="</form>\n";
        	}

	require ("header.php");
?>
<div style="padding:10px">
<center>
<table summary='eintragen' class="rahmen" cellspacing="0" cellpadding="5">
	<tr>
		<td class="rahmen_titel">
                <font style="color:<?php echo $settings['ueberschriftfarbe']; ?>"><b><?php echo $lang['title_message_send_email_before_name']."&nbsp;".$username."&nbsp;".$lang['title_message_send_email_after_name']; ?></b></font>
                </td>
	</tr>
	<tr>
         	<td class="rahmen_eintraege">
                <center>
                <br>
                <?php
                 	echo "<div style='padding-bottom:7px'>".$fehler."</div>";
                        echo $ausgabe;
                ?>
                </center>
		</td>
	</tr>
</table>
<div style="padding:10px"><font><a href='guestbook.php'><?php echo $lang['back_to_gb']; ?></a></font></div></center>
<?php
	include ("copyright.php");
?>
</div>
<?php
	include ("footer.php");
?>
